@@ -1,26 +1,24 @@
 /* macvt.c */
 
 /*----------------------------------------------------------------------
--- This file is a part of the MARST package.
+-- Copyright (C) 2000, 2001, 2002 Free Software Foundation, Inc.
 --
--- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                          Department for Applied Informatics,
---                          Moscow Aviation Institute, Moscow, Russia.
---                          All rights reserved.
+-- This file is part of GNU MARST.
 --
--- This code is free software; you can redistribute it and/or modify
+-- GNU MARST is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2 of the License, or
--- (at your option) any later version.
+-- the Free Software Foundation; either version 2, or (at your option)
+-- any later version.
 --
--- This software is distributed "as is" in the hope that it will be
--- useful, but WITHOUT ANY WARRANTY; without even the implied warranty
--- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+-- GNU MARST is distributed in the hope that it will be useful, but
+-- WITHOUT ANY WARRANTY; without even the implied warranty of
+-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 -- General Public License for more details.
 --
 -- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
+-- along with GNU MARST; see the file COPYING. If not, write to the
+-- Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
+-- MA 02111-1307, USA.
 ----------------------------------------------------------------------*/
 
 #include <ctype.h>
@@ -32,7 +30,7 @@
 
 /*--------------------------------------------------------------------*/
 
-static char *version = "MACVT -- Algol 60 Converter, Version 2.2";
+static char *version = "MACVT -- Algol 60 Converter, Version 2.4";
 /* Version information. */
 
 static char *infilename = "";
@@ -41,7 +39,7 @@ static char *infilename = "";
    This name used in error messages. */
 
 static FILE *infile;
-/* The stream connected with the input text file. */
+/* The stream connected to the input text file. */
 
 static char *outfilename = "";
 /* The name of output text file to which the converter emits converted
@@ -49,7 +47,7 @@ static char *outfilename = "";
    name is "(stdout)". */
 
 static FILE *outfile;
-/* The stream connected with the output text file. */
+/* The stream connected to the output text file. */
 
 static int free_coding = 0;
 /* Free coding flag. If this flag is set then free representation of
@@ -961,8 +959,8 @@ static void display_help(char *my_name)
 
 static void display_version(void)
 {     printf("%s\n", version);
-      printf("Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet."
-         "ru, mao@gnu.org>\n");
+      printf("Copyright (C) 2000, 2001, 2002 Free Software Foundation, "
+         "Inc.\n");
       printf("This program is free software; you may redistribute it un"
          "der the terms of\n");
       printf("the GNU General Public License. This program has absolute"
